@@ -3,27 +3,20 @@
 
 #include "spvm_typedecl.h"
 
-enum {
-  SPVM_FIELD_C_FLAG_PRIVATE = 1,
-  SPVM_FIELD_C_FLAG_PUBLIC = 2,
-};
-
 struct spvm_field {
+  SPVM_OP* op_field;
+  SPVM_OP* op_name;
   const char* name;
   const char* signature;
+  SPVM_TYPE* type;
+  SPVM_CLASS* class;
   int32_t id;
   int32_t index;
   int32_t offset;
-  int32_t type_id; // tmp
-  SPVM_TYPE* type;
-  SPVM_CLASS* class;
-  SPVM_OP* op_field;
-  SPVM_OP* op_name;
-  int32_t flag;
-  int32_t type_category;
-  int32_t is_captured;
-  int32_t has_setter;
-  int32_t has_getter;
+  int8_t is_captured;
+  int8_t has_setter;
+  int8_t has_getter;
+  int8_t is_public;
 };
 
 SPVM_FIELD* SPVM_FIELD_new(SPVM_COMPILER* compiler);
