@@ -3,22 +3,6 @@
 
 #include "spvm_typedecl.h"
 
-enum {
-  SPVM_METHOD_C_CALL_TYPE_ID_CLASS_METHOD,
-  SPVM_METHOD_C_CALL_TYPE_ID_INSTANCE_METHOD,
-};
-
-enum {
-  SPVM_METHOD_C_FLAG_NATIVE = 1,
-  SPVM_METHOD_C_FLAG_PRECOMPILE = 2,
-  SPVM_METHOD_C_FLAG_ENUM = 4,
-  SPVM_METHOD_C_FLAG_DESTRUCTOR = 8,
-  SPVM_METHOD_C_FLAG_OBJECT_TYPE_RETURN = 16,
-  SPVM_METHOD_C_FLAG_MULTI_NUMERIC_TYPE_RETURN = 32,
-  SPVM_METHOD_C_FLAG_ANON = 64,
-  SPVM_METHOD_C_FLAG_PRIVATE = 128,
-};
-
 // Method information
 struct spvm_method {
   const char* name;
@@ -33,14 +17,12 @@ struct spvm_method {
   SPVM_CLASS* class;
   const char* accessor_original_name;
   const char* anon_method_defined_class_name;
-  void* precompile_address;
-  void* native_address;
+  SPVM_OP* op_inline;
   int32_t args_length;
   int32_t id;
   int32_t tmp_vars_length;
   int32_t opcodes_base_id;
   int32_t opcodes_length;
-  int32_t flag;
   int32_t call_stack_byte_vars_length;
   int32_t call_stack_short_vars_length;
   int32_t call_stack_int_vars_length;
@@ -49,6 +31,7 @@ struct spvm_method {
   int32_t call_stack_double_vars_length;
   int32_t call_stack_object_vars_length;
   int32_t call_stack_ref_vars_length;
+  int32_t mortal_stack_length;
   int32_t anon_method_id;
   int8_t have_vaarg;
   int8_t is_class_var_setter;
@@ -60,8 +43,12 @@ struct spvm_method {
   int8_t can_precompile;
   int8_t is_class_method;
   int8_t is_init;
-  int32_t mortal_stack_length;
-  SPVM_OP* op_inline;
+  int8_t is_private;
+  int8_t is_destructor;
+  int8_t is_enum;
+  int8_t is_precompile;
+  int8_t is_native;
+  int8_t is_anon;
 };
 
 SPVM_METHOD* SPVM_METHOD_new(SPVM_COMPILER* compiler);
