@@ -386,45 +386,204 @@ int32_t SPVM_COMPILER_compile_spvm(SPVM_COMPILER* compiler, const char* class_na
   return error_code;
 }
 
-void SPVM_COMPILER_build_runtime(SPVM_COMPILER* compiler, SPVM_RUNTIME* runtime) {
+int32_t SPVM_COMPILER_calculate_spvm_32bit_codes_length(SPVM_COMPILER* compiler) {
 
-  SPVM_ALLOCATOR* allocator = runtime->allocator;
-
-  runtime->opcodes = SPVM_ALLOCATOR_alloc_memory_block_permanent(allocator, sizeof(SPVM_OPCODE) * (compiler->opcode_array->length + 1));
-  runtime->opcodes_length = compiler->opcode_array->length;
-  memcpy(runtime->opcodes, compiler->opcode_array->values, sizeof(SPVM_OPCODE) * compiler->opcode_array->length);
+  int32_t length = 0;
   
-  // String buffers
-  runtime->constant_strings_buffer_length = compiler->constant_strings_buffer->length;
-  runtime->constant_strings_buffer = (const char*)SPVM_ALLOCATOR_alloc_memory_block_permanent(allocator, compiler->constant_strings_buffer->length + 1);
-  memcpy((char*)runtime->constant_strings_buffer, compiler->constant_strings_buffer->value, compiler->constant_strings_buffer->length);
-
+  // opcodes length
+  length++;
   
-  // Strings
-  runtime->constant_strings_length = compiler->constant_strings->length;
-  runtime->constant_strings = SPVM_ALLOCATOR_alloc_memory_block_permanent(allocator, sizeof(SPVM_RUNTIME_CONSTANT_STRING) * (compiler->constant_strings->length + 1));
+  // opcodes 32bit length
+  length++;
+  
+  // opcodes
+  length += (sizeof(SPVM_OPCODE) / sizeof(int32_t)) * (compiler->opcode_array->length + 1);
+
+  // constant_strings_buffer length
+  length++;
+
+  // constant_strings_buffer 32bit length
+  length++;
+  
+  // constant_strings_buffer
+  length += (compiler->constant_strings_buffer->length / sizeof(int32_t)) + 1;
+  
+  // constant_strings length
+  length++;
+
+  // constant_strings 32bit length
+  length++;
+  
+  // constant_strings
+  length += (sizeof(SPVM_RUNTIME_CONSTANT_STRING) / sizeof(int32_t)) * (compiler->constant_strings->length + 1);
+
+  // anon_method_methods length
+  length++;
+
+  // anon_method_methods 32bit length
+  length++;
+
+  // anon_method_method_ids
+  length += (sizeof(int32_t) / sizeof(int32_t)) * (compiler->anon_methods->length + 1);
+
+  // classes length
+  length++;
+  
+  // classes 32bit length
+  length++;
+  
+  // classes
+  length += (sizeof(SPVM_RUNTIME_CLASS) / sizeof(int32_t)) * (compiler->classes->length + 1);
+
+  // basic_types length
+  length++;
+
+  // basic_types 32bit length
+  length++;
+  
+  // basic_types
+  length += (sizeof(SPVM_RUNTIME_BASIC_TYPE) / sizeof(int32_t)) * (compiler->basic_types->length + 1);
+
+  // types length
+  length++;
+
+  // types 32bit length
+  length++;
+  
+  // types
+  length += (sizeof(SPVM_RUNTIME_TYPE) / sizeof(int32_t)) * (compiler->types->length + 1);
+
+  // class_vars length
+  length++;
+
+  // class_vars 32bit length
+  length++;
+  
+  // class_vars
+  length += (sizeof(SPVM_RUNTIME_CLASS_VAR) / sizeof(int32_t)) * (compiler->class_vars->length + 1);
+
+  // methods length
+  length++;
+  
+  // methods 32bit length
+  length++;
+  
+  // methods
+  length += (sizeof(SPVM_RUNTIME_METHOD) / sizeof(int32_t)) * (compiler->methods->length + 1);
+
+  // arg_types length
+  length++;
+  
+  // arg_types 32bit length
+  length++;
+  
+  // arg_type_ids
+  length += (sizeof(int32_t) / sizeof(int32_t)) * (compiler->args->length + 1);
+  
+  // fields length
+  length++;
+
+  // fields 32bit length
+  length++;
+  
+  // fields
+  length += (sizeof(SPVM_RUNTIME_FIELD) / sizeof(int32_t)) * (compiler->fields->length + 1);
+  
+  return length;
+}
+
+int32_t* SPVM_COMPILER_create_spvm_32bit_codes(SPVM_COMPILER* compiler, SPVM_ALLOCATOR* allocator) {
+  
+  int32_t spvm_32bit_codes_length = SPVM_COMPILER_calculate_spvm_32bit_codes_length(compiler);
+  int32_t* spvm_32bit_codes = SPVM_ALLOCATOR_alloc_memory_block_permanent(allocator, sizeof(int32_t) * spvm_32bit_codes_length);
+
+  int32_t* spvm_32bit_codes_ptr = spvm_32bit_codes;
+  
+  // Total length
+  *spvm_32bit_codes_ptr = spvm_32bit_codes_length;
+  spvm_32bit_codes_ptr++;
+  
+  // opcodes length
+  *spvm_32bit_codes_ptr = compiler->opcode_array->length;
+  spvm_32bit_codes_ptr++;
+  
+  // opcodes 32bit length
+  int32_t opcodes_32bit_length = (sizeof(SPVM_OPCODE) / sizeof(int32_t)) * (compiler->opcode_array->length + 1);
+  *spvm_32bit_codes_ptr = opcodes_32bit_length;
+  spvm_32bit_codes_ptr++;
+  
+  // opcodes
+  memcpy(spvm_32bit_codes_ptr, compiler->opcode_array->values, sizeof(int32_t) * opcodes_32bit_length);
+  spvm_32bit_codes_ptr += opcodes_32bit_length;
+  
+  // constant_strings_buffer length
+  *spvm_32bit_codes_ptr = compiler->constant_strings_buffer->length;
+  spvm_32bit_codes_ptr++;
+
+  // constant_strings_buffer 32bit length
+  int32_t constant_strings_buffer_32bit_length = (compiler->constant_strings_buffer->length / sizeof(int32_t)) + 1;
+  *spvm_32bit_codes_ptr = constant_strings_buffer_32bit_length;
+  spvm_32bit_codes_ptr++;
+  
+  // constant_strings_buffer
+  memcpy(spvm_32bit_codes_ptr, compiler->constant_strings_buffer->value, sizeof(int32_t) * constant_strings_buffer_32bit_length);
+  spvm_32bit_codes_ptr += constant_strings_buffer_32bit_length;
+  
+  // constant_strings length
+  *spvm_32bit_codes_ptr = compiler->constant_strings->length;
+  spvm_32bit_codes_ptr++;
+
+  // constant_strings 32bit length
+  int32_t constant_strings_32bit_length = (sizeof(SPVM_RUNTIME_CONSTANT_STRING) / sizeof(int32_t)) * (compiler->constant_strings->length + 1);
+  *spvm_32bit_codes_ptr = constant_strings_32bit_length;
+  spvm_32bit_codes_ptr++;
+  
+  // constant_strings
+  int32_t* constant_string_32bit_ptr = spvm_32bit_codes_ptr;
   for (int32_t constant_string_id = 0; constant_string_id < compiler->constant_strings->length; constant_string_id++) {
     SPVM_CONSTANT_STRING* string = SPVM_LIST_get(compiler->constant_strings, constant_string_id);
-    SPVM_RUNTIME_CONSTANT_STRING* runtime_string = &runtime->constant_strings[constant_string_id];
+    SPVM_RUNTIME_CONSTANT_STRING* runtime_string = (SPVM_RUNTIME_CONSTANT_STRING*)constant_string_32bit_ptr;
     
     runtime_string->id = string->id;
     runtime_string->length = string->length;
     runtime_string->string_buffer_id = string->string_buffer_id;
+    constant_string_32bit_ptr += sizeof(SPVM_RUNTIME_CONSTANT_STRING) / sizeof(int32_t);
   }
+  spvm_32bit_codes_ptr += constant_strings_32bit_length;
 
-  // Runtime classes
-  runtime->classes_length = compiler->classes->length;
-  runtime->classes = SPVM_ALLOCATOR_alloc_memory_block_permanent(allocator, sizeof(SPVM_RUNTIME_CLASS) * (compiler->classes->length + 1));
-  runtime->anon_method_methods_length = compiler->anon_methods->length;
-  runtime->anon_method_method_ids = SPVM_ALLOCATOR_alloc_memory_block_permanent(allocator, sizeof(int32_t) * (compiler->anon_methods->length + 1));
+  // anon_method_methods length
+  *spvm_32bit_codes_ptr = compiler->anon_methods->length;
+  spvm_32bit_codes_ptr++;
+
+  // anon_method_methods 32bit length
+  int32_t anon_method_32bit_length = (sizeof(int32_t) / sizeof(int32_t)) * (compiler->anon_methods->length + 1);
+  *spvm_32bit_codes_ptr = anon_method_32bit_length;
+  spvm_32bit_codes_ptr++;
+
+  // anon_method_method_ids
+  int32_t* anon_method_32bit_ptr = spvm_32bit_codes_ptr;
   for (int32_t anon_method_id = 0; anon_method_id < compiler->anon_methods->length; anon_method_id++) {
     SPVM_METHOD* anon_method = SPVM_LIST_get(compiler->anon_methods, anon_method_id);
     int32_t anon_method_id = anon_method->anon_method_id;
-    runtime->anon_method_method_ids[anon_method_id] = anon_method->id;
+    *anon_method_32bit_ptr = anon_method->id;
+    anon_method_32bit_ptr += sizeof(int32_t) / sizeof(int32_t);
   }
+  spvm_32bit_codes_ptr += anon_method_32bit_length;
+
+  // classes length
+  *spvm_32bit_codes_ptr = compiler->classes->length;
+  spvm_32bit_codes_ptr++;
+
+  // classes 32bit length
+  int32_t classes_32bit_length = (sizeof(SPVM_RUNTIME_CLASS) / sizeof(int32_t)) * (compiler->classes->length + 1);
+  *spvm_32bit_codes_ptr = classes_32bit_length;
+  spvm_32bit_codes_ptr++;
+
+  // classes
+  int32_t* class_32bit_ptr = spvm_32bit_codes_ptr;
   for (int32_t class_id = 0; class_id < compiler->classes->length; class_id++) {
     SPVM_CLASS* class = SPVM_LIST_get(compiler->classes, class_id);
-    SPVM_RUNTIME_CLASS* runtime_class = &runtime->classes[class_id];
+    SPVM_RUNTIME_CLASS* runtime_class = (SPVM_RUNTIME_CLASS*)class_32bit_ptr;
     
     runtime_class->type_id = class->type->id;
     runtime_class->id = class->id;
@@ -438,20 +597,20 @@ void SPVM_COMPILER_build_runtime(SPVM_COMPILER* compiler, SPVM_RUNTIME* runtime)
     else {
       runtime_class->module_dir_id = -1;
     }
-    runtime_class->flag = class->flag;
     runtime_class->object_fields_length = class->object_fields_length;
     runtime_class->object_fields_offset = class->object_fields_offset;
     runtime_class->has_init_block = class->has_init_block;
     runtime_class->is_anon = class->is_anon;
+    runtime_class->is_pointer = class->is_pointer;
 
     SPVM_CONSTANT_STRING* class_string = SPVM_HASH_get(compiler->constant_string_symtable, class->name, strlen(class->name));
     runtime_class->name_id = class_string->id;
     
-    if (class->method_destructor) {
-      runtime_class->method_destructor_id = class->method_destructor->id;
+    if (class->destructor_method) {
+      runtime_class->destructor_method_id = class->destructor_method->id;
     }
     else {
-      runtime_class->method_destructor_id = -1;
+      runtime_class->destructor_method_id = -1;
     }
     
     runtime_class->methods_length = class->methods->length;
@@ -481,13 +640,13 @@ void SPVM_COMPILER_build_runtime(SPVM_COMPILER* compiler, SPVM_RUNTIME* runtime)
       runtime_class->class_vars_base_id = -1;
     }
 
-    runtime_class->interface_classes_length = class->interface_classes->length;
-    if (class->interface_classes->length > 0) {
-      SPVM_CLASS* interface_class = SPVM_LIST_get(class->interface_classes, 0);
-      runtime_class->interface_classes_base_id = interface_class->id;
+    runtime_class->interfaces_length = class->interfaces->length;
+    if (class->interfaces->length > 0) {
+      SPVM_CLASS* interface = SPVM_LIST_get(class->interfaces, 0);
+      runtime_class->interfaces_base_id = interface->id;
     }
     else {
-      runtime_class->interface_classes_base_id = -1;
+      runtime_class->interfaces_base_id = -1;
     }
 
     runtime_class->anon_methods_length = class->anon_methods->length;
@@ -499,16 +658,24 @@ void SPVM_COMPILER_build_runtime(SPVM_COMPILER* compiler, SPVM_RUNTIME* runtime)
       runtime_class->anon_methods_base_id = -1;
     }
 
-    SPVM_RUNTIME_CONSTANT_STRING* class_name_string = (SPVM_RUNTIME_CONSTANT_STRING*)&runtime->constant_strings[runtime_class->name_id];
-    const char* runtime_class_name = (const char*)&runtime->constant_strings_buffer[class_name_string->string_buffer_id];
+    class_32bit_ptr += sizeof(SPVM_RUNTIME_CLASS) / sizeof(int32_t);
   }
+  spvm_32bit_codes_ptr += classes_32bit_length;
 
-  // Runtime basic types
-  runtime->basic_types_length = compiler->basic_types->length;
-  runtime->basic_types = SPVM_ALLOCATOR_alloc_memory_block_permanent(allocator, sizeof(SPVM_RUNTIME_BASIC_TYPE) * (compiler->basic_types->length + 1));
+  // basic_types length
+  *spvm_32bit_codes_ptr = compiler->basic_types->length;
+  spvm_32bit_codes_ptr++;
+
+  // basic_types 32bit length
+  int32_t basic_types_32bit_length = (sizeof(SPVM_RUNTIME_BASIC_TYPE) / sizeof(int32_t)) * (compiler->basic_types->length + 1);
+  *spvm_32bit_codes_ptr = basic_types_32bit_length;
+  spvm_32bit_codes_ptr++;
+
+  // basic_types
+  int32_t* basic_type_32bit_ptr = spvm_32bit_codes_ptr;
   for (int32_t basic_type_id = 0; basic_type_id < compiler->basic_types->length; basic_type_id++) {
     SPVM_BASIC_TYPE* basic_type = SPVM_LIST_get(compiler->basic_types, basic_type_id);
-    SPVM_RUNTIME_BASIC_TYPE* runtime_basic_type = &runtime->basic_types[basic_type_id];
+    SPVM_RUNTIME_BASIC_TYPE* runtime_basic_type = (SPVM_RUNTIME_BASIC_TYPE*)basic_type_32bit_ptr;
     
     runtime_basic_type->id = basic_type->id;
     runtime_basic_type->category = basic_type->category;
@@ -520,28 +687,50 @@ void SPVM_COMPILER_build_runtime(SPVM_COMPILER* compiler, SPVM_RUNTIME* runtime)
     }
     SPVM_CONSTANT_STRING* basic_type_string = SPVM_HASH_get(compiler->constant_string_symtable, basic_type->name, strlen(basic_type->name));
     runtime_basic_type->name_id = basic_type_string->id;
-  }
 
-  // Runtime types
-  runtime->types_length = compiler->types->length;
-  runtime->types = SPVM_ALLOCATOR_alloc_memory_block_permanent(allocator, sizeof(SPVM_RUNTIME_TYPE) * (compiler->types->length + 1));
+    basic_type_32bit_ptr += sizeof(SPVM_RUNTIME_BASIC_TYPE) / sizeof(int32_t);
+  }
+  spvm_32bit_codes_ptr += basic_types_32bit_length;
+
+  // types length
+  *spvm_32bit_codes_ptr = compiler->types->length;
+  spvm_32bit_codes_ptr++;
+
+  // types 32bit length
+  int32_t types_32bit_length = (sizeof(SPVM_RUNTIME_TYPE) / sizeof(int32_t)) * (compiler->types->length + 1);
+  *spvm_32bit_codes_ptr = types_32bit_length;
+  spvm_32bit_codes_ptr++;
+
+  // types
+  int32_t* type_32bit_ptr = spvm_32bit_codes_ptr;
   for (int32_t type_id = 0; type_id < compiler->types->length; type_id++) {
     SPVM_TYPE* type = SPVM_LIST_get(compiler->types, type_id);
-    SPVM_RUNTIME_TYPE* runtime_type = &runtime->types[type_id];
+    SPVM_RUNTIME_TYPE* runtime_type = (SPVM_RUNTIME_TYPE*)type_32bit_ptr;
     
     runtime_type->basic_type_id = type->basic_type->id;
     runtime_type->dimension = type->dimension;
     runtime_type->flag = type->flag;
     runtime_type->width = type->width;
     runtime_type->mulnum_field_basic_type_id = SPVM_TYPE_get_mulnum_field_basic_type_id(compiler, type->basic_type->id, type->dimension, type->flag);
-  }
 
-  // Runtime class variables
-  runtime->class_vars_length = compiler->class_vars->length;
-  runtime->class_vars = SPVM_ALLOCATOR_alloc_memory_block_permanent(allocator, sizeof(SPVM_RUNTIME_CLASS_VAR) * (compiler->class_vars->length + 1));
+    type_32bit_ptr += sizeof(SPVM_RUNTIME_TYPE) / sizeof(int32_t);
+  }
+  spvm_32bit_codes_ptr += types_32bit_length;
+
+  // class_vars length
+  *spvm_32bit_codes_ptr = compiler->class_vars->length;
+  spvm_32bit_codes_ptr++;
+
+  // class_vars 32bit length
+  int32_t class_vars_32bit_length = (sizeof(SPVM_RUNTIME_CLASS_VAR) / sizeof(int32_t)) * (compiler->class_vars->length + 1);
+  *spvm_32bit_codes_ptr = class_vars_32bit_length;
+  spvm_32bit_codes_ptr++;
+
+  // class_vars
+  int32_t* class_var_32bit_ptr = spvm_32bit_codes_ptr;
   for (int32_t class_var_id = 0; class_var_id < compiler->class_vars->length; class_var_id++) {
     SPVM_CLASS_VAR* class_var = SPVM_LIST_get(compiler->class_vars, class_var_id);
-    SPVM_RUNTIME_CLASS_VAR* runtime_class_var = &runtime->class_vars[class_var_id];
+    SPVM_RUNTIME_CLASS_VAR* runtime_class_var = (SPVM_RUNTIME_CLASS_VAR*)class_var_32bit_ptr;
 
     runtime_class_var->id = class_var->id;
     runtime_class_var->type_id = class_var->type->id;
@@ -552,23 +741,33 @@ void SPVM_COMPILER_build_runtime(SPVM_COMPILER* compiler, SPVM_RUNTIME* runtime)
 
     SPVM_CONSTANT_STRING* class_var_signature_string = SPVM_HASH_get(compiler->constant_string_symtable, class_var->signature, strlen(class_var->signature));
     runtime_class_var->signature_id = class_var_signature_string->id;
-  }
 
-  // Runtime methods
-  runtime->methods_length = compiler->methods->length;
-  runtime->methods = SPVM_ALLOCATOR_alloc_memory_block_permanent(allocator, sizeof(SPVM_RUNTIME_METHOD) * (compiler->methods->length + 1));
+    class_var_32bit_ptr += sizeof(SPVM_RUNTIME_CLASS_VAR) / sizeof(int32_t);
+  }
+  spvm_32bit_codes_ptr += class_vars_32bit_length;
+
+  // methods length
+  *spvm_32bit_codes_ptr = compiler->methods->length;
+  spvm_32bit_codes_ptr++;
+
+  // methods 32bit length
+  int32_t methods_32bit_length = (sizeof(SPVM_RUNTIME_METHOD) / sizeof(int32_t)) * (compiler->methods->length + 1);
+  *spvm_32bit_codes_ptr = methods_32bit_length;
+  spvm_32bit_codes_ptr++;
+
+  // methods
+  int32_t* method_32bit_ptr = spvm_32bit_codes_ptr;
   for (int32_t method_id = 0; method_id < compiler->methods->length; method_id++) {
     SPVM_METHOD* method = SPVM_LIST_get(compiler->methods, method_id);
-    SPVM_RUNTIME_METHOD* runtime_method = &runtime->methods[method_id];
+    SPVM_RUNTIME_METHOD* runtime_method = (SPVM_RUNTIME_METHOD*)method_32bit_ptr;
 
     runtime_method->opcodes_base_id = method->opcodes_base_id;
     runtime_method->opcodes_length = method->opcodes_length;
     runtime_method->id = method->id;
     runtime_method->class_id = method->class->id;
-    runtime_method->flag = method->flag;
     runtime_method->is_class_method = method->is_class_method;
     runtime_method->is_init = method->is_init;
-    runtime_method->is_anon = method->flag & SPVM_METHOD_C_FLAG_ANON;
+    runtime_method->is_anon = method->is_anon;
     runtime_method->call_stack_byte_vars_length  = method->call_stack_byte_vars_length;
     runtime_method->call_stack_short_vars_length  = method->call_stack_short_vars_length;
     runtime_method->call_stack_int_vars_length  = method->call_stack_int_vars_length;
@@ -579,6 +778,8 @@ void SPVM_COMPILER_build_runtime(SPVM_COMPILER* compiler, SPVM_RUNTIME* runtime)
     runtime_method->call_stack_ref_vars_length = method->call_stack_ref_vars_length;
     runtime_method->mortal_stack_length  = method->mortal_stack_length;
     runtime_method->return_type_id = method->return_type->id;
+    runtime_method->is_native = method->is_native;
+    runtime_method->is_precompile = method->is_precompile;
 
     SPVM_CONSTANT_STRING* method_name_string = SPVM_HASH_get(compiler->constant_string_symtable, method->name, strlen(method->name));
     runtime_method->name_id = method_name_string->id;
@@ -594,29 +795,45 @@ void SPVM_COMPILER_build_runtime(SPVM_COMPILER* compiler, SPVM_RUNTIME* runtime)
     else {
       runtime_method->args_base_id = -1;
     }
-  }
-  
-  // Method native addresses
-  runtime->method_native_addresses = SPVM_ALLOCATOR_alloc_memory_block_permanent(allocator, sizeof(void*) * runtime->methods_length);
-  
-  // Method precompile addresses
-  runtime->method_precompile_addresses = SPVM_ALLOCATOR_alloc_memory_block_permanent(allocator, sizeof(void*) * runtime->methods_length);
 
-  // Runtime method argument type ids
-  runtime->arg_types_length = compiler->args->length;
-  runtime->arg_type_ids = SPVM_ALLOCATOR_alloc_memory_block_permanent(allocator, sizeof(int32_t) * (compiler->args->length + 1));
+    method_32bit_ptr += sizeof(SPVM_RUNTIME_METHOD) / sizeof(int32_t);
+  }
+  spvm_32bit_codes_ptr += methods_32bit_length;
+
+  // args length
+  *spvm_32bit_codes_ptr = compiler->args->length;
+  spvm_32bit_codes_ptr++;
+
+  // arg_type_method_ids 32bit length
+  int32_t arg_type_ids_32bit_length = (sizeof(int32_t) / sizeof(int32_t)) * (compiler->args->length + 1);
+  *spvm_32bit_codes_ptr = arg_type_ids_32bit_length;
+  spvm_32bit_codes_ptr++;
+
+  // arg_type_method_ids
+  int32_t* arg_type_id_32bit_ptr = spvm_32bit_codes_ptr;
   for (int32_t arg_id = 0; arg_id < compiler->args->length; arg_id++) {
     SPVM_VAR_DECL* arg_var_decl = SPVM_LIST_get(compiler->args, arg_id);
     int32_t arg_type_id = arg_var_decl->type->id;
-    runtime->arg_type_ids[arg_id] = arg_type_id;
+    *arg_type_id_32bit_ptr = arg_type_id;
+    
+    arg_type_id_32bit_ptr += sizeof(int32_t) / sizeof(int32_t);
   }
+  spvm_32bit_codes_ptr += arg_type_ids_32bit_length;
 
-  // Runtime fields
-  runtime->fields_length = compiler->fields->length;
-  runtime->fields = SPVM_ALLOCATOR_alloc_memory_block_permanent(allocator, sizeof(SPVM_RUNTIME_FIELD) * (compiler->fields->length + 1));
+  // fields length
+  *spvm_32bit_codes_ptr = compiler->fields->length;
+  spvm_32bit_codes_ptr++;
+
+  // fields 32bit length
+  int32_t fields_32bit_length = (sizeof(SPVM_RUNTIME_FIELD) / sizeof(int32_t)) * (compiler->fields->length + 1);
+  *spvm_32bit_codes_ptr = fields_32bit_length;
+  spvm_32bit_codes_ptr++;
+
+  // fields
+  int32_t* field_32bit_ptr = spvm_32bit_codes_ptr;
   for (int32_t field_id = 0; field_id < compiler->fields->length; field_id++) {
     SPVM_FIELD* field = SPVM_LIST_get(compiler->fields, field_id);
-    SPVM_RUNTIME_FIELD* runtime_field = &runtime->fields[field_id];
+    SPVM_RUNTIME_FIELD* runtime_field = (SPVM_RUNTIME_FIELD*)field_32bit_ptr;
 
     runtime_field->id = field->id;
     runtime_field->index = field->index;
@@ -629,24 +846,12 @@ void SPVM_COMPILER_build_runtime(SPVM_COMPILER* compiler, SPVM_RUNTIME* runtime)
 
     SPVM_CONSTANT_STRING* field_signature_string = SPVM_HASH_get(compiler->constant_string_symtable, field->signature, strlen(field->signature));
     runtime_field->signature_id = field_signature_string->id;
+
+    field_32bit_ptr += sizeof(SPVM_RUNTIME_FIELD) / sizeof(int32_t);
   }
-
-#ifdef SPVM_DEBUG_RUNTIME
-  fprintf(stderr, "[RUNTIME MEMORY SIZE]\n");
-  fprintf(stderr, "opcodes size: %d bytes\n", (int32_t)(sizeof(SPVM_OPCODE) * runtime->opcodes_length));
-  fprintf(stderr, "string_buffer size: %d bytes\n", (int32_t)(runtime->constant_strings_buffer_length));
-  fprintf(stderr, "strings size: %d bytes\n", (int32_t)(sizeof(SPVM_RUNTIME_CONSTANT_STRING) * runtime->constant_strings_length));
-  fprintf(stderr, "classes size: %d bytes\n", (int32_t)(sizeof(SPVM_RUNTIME_CLASS) * runtime->classes_length));
-  fprintf(stderr, "basic_types size: %d bytes\n", (int32_t)(sizeof(SPVM_RUNTIME_BASIC_TYPE) * runtime->basic_types_length));
-  fprintf(stderr, "types size: %d bytes\n", (int32_t)(sizeof(SPVM_RUNTIME_TYPE) * runtime->types_length));
-  fprintf(stderr, "class_vars size: %d bytes\n", (int32_t)(sizeof(SPVM_RUNTIME_CLASS_VAR) * runtime->class_vars_length));
-  fprintf(stderr, "methods size: %d bytes\n", (int32_t)(sizeof(SPVM_RUNTIME_METHOD) * runtime->methods_length));
-  fprintf(stderr, "method_native_addresses size: %d bytes\n", (int32_t)(sizeof(void*) * runtime->methods_length));
-  fprintf(stderr, "method_native_precompile size: %d bytes\n", (int32_t)(sizeof(void*) * runtime->methods_length));
-  fprintf(stderr, "arg_type_ids size: %d bytes\n", (int32_t)(sizeof(int32_t) * runtime->arg_types_length));
-  fprintf(stderr, "fields size: %d bytes\n", (int32_t)(sizeof(SPVM_RUNTIME_FIELD) * runtime->fields_length));
-#endif
-
+  spvm_32bit_codes_ptr += fields_32bit_length;
+  
+  return spvm_32bit_codes;
 }
 
 void SPVM_COMPILER_error(SPVM_COMPILER* compiler, const char* message_template, ...) {
